| add_filter | R Documentation |
Add filter definition
add_filter(x, filter, step_id, ...)
## S3 method for class 'Cohort'
add_filter(
x,
filter,
step_id,
run_flow = FALSE,
hook = list(pre = get_hook("pre_add_filter_hook"), post =
get_hook("post_add_filter_hook")),
...
)
## S3 method for class 'Source'
add_filter(x, filter, step_id, ...)
x |
An object to add filter to. |
filter |
Filter definition created with filter. |
step_id |
Id of the step to add the filter to. If missing, filter is added to the last step. |
... |
Other parameters passed to specific S3 method. |
run_flow |
If 'TRUE', data flow is run after the filter is added. |
hook |
List of hooks describing methods to run before/after the filter is added. See hooks for more details. |
Method dependent object (i.e. 'Cohort' or 'Source') having filter added in selected step.
managing-cohort, managing-source
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.