cb_tool_add_filters: Create a tool for adding filters to a cohort

View source: R/ai_tools.R

cb_tool_add_filtersR Documentation

Create a tool for adding filters to a cohort

Description

Returns a cb_tool that adds selected filters from the source's available_filters to the cohort. The LLM chooses whether to add to a new step or the existing last step via the action argument.

Usage

cb_tool_add_filters(cohort)

Arguments

cohort

A Cohort object.

Value

A cb_tool object.


cohortBuilder documentation built on July 3, 2026, 9:07 a.m.