cb_tool_remove_filters: Create a tool for removing filters from the cohort

View source: R/ai_tools.R

cb_tool_remove_filtersR Documentation

Create a tool for removing filters from the cohort

Description

Returns a cb_tool that removes filters from a step in the cohort. If removing all filters from a step, the entire step is removed.

Usage

cb_tool_remove_filters(cohort)

Arguments

cohort

A Cohort object.

Value

A cb_tool object.


cohortBuilder documentation built on July 3, 2026, 9:07 a.m.