Skip to contents

Returns a cb_tool that updates filter parameter values on the last step of the cohort and triggers the data pipeline.

Usage

cb_tool_set_filter_values(cohort)

Arguments

cohort

A Cohort object.

Value

A cb_tool object.