| filter_effective_value | R Documentation |
Returns the value that should be used to pre-select the filter input, accounting for the domain. This is the filter's value intersected with its domain; when the value is unset ('NA') and a domain is present, the domain is returned as the effective value. Thin wrapper over [cb_intersect_domain()] for use by GUIs.
filter_effective_value(filter)
filter |
S7 filter object. |
The effective value for the filter, suitable for pre-selecting an input. Structure depends on the filter type.
[filter_domain()], [cb_intersect_domain()]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.