Returns the column name(s) a filter is bound to, regardless of whether the filter stores them in a single-variable property (`variable`) or a multi-variable property (`variables`).
Returns the column name(s) a filter is bound to, regardless of whether the filter stores them in a single-variable property (`variable`) or a multi-variable property (`variables`).