managing-source: Managing the Source object

managing-sourceR Documentation

Managing the Source object

Description

The list of methods designed for managing the Source configuration and state.

  • add_step - Add step to Source object.

  • rm_step - Remove step from Source object.

  • add_filter - Add filter to Source step.

  • rm_filter - Remove filter from Source step.

  • update_filter - Update filter configuration.

Value

The object of class 'Source' having the modified configuration dependent on the used method.

See Also

managing-cohort


cohortBuilder documentation built on July 3, 2026, 9:07 a.m.