| rm_filter | R Documentation |
Remove filter definition
rm_filter(x, step_id, filter_id, ...)
## S3 method for class 'Cohort'
rm_filter(
x,
step_id,
filter_id,
run_flow = FALSE,
hook = list(pre = get_hook("pre_rm_filter_hook"), post =
get_hook("post_rm_filter_hook")),
...
)
## S3 method for class 'Source'
rm_filter(x, step_id, filter_id, ...)
x |
An object from which filter should be removed. |
step_id |
Id of the step from which filter should be removed. |
filter_id |
Id of the filter to be removed. |
... |
Other parameters passed to specific S3 method. |
run_flow |
If 'TRUE', data flow is run after the filter is removed. |
hook |
List of hooks describing methods to run before/after the filter is removed. See hooks for more details. |
Method dependent object (i.e. 'Cohort' or 'Source') having selected filter removed.
managing-cohort, managing-source
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.