S7 representation of the built-in `tblist` source class, used as the source side of S7 dual dispatch when registering filter methods (e.g. `S7::method(cb_filter_data, list(CbFilterDiscrete, tblist_class))`). See `vignette("custom-filters")`.
S7 representation of the built-in `tblist` source class, used as the source side of S7 dual dispatch when registering filter methods (e.g. `S7::method(cb_filter_data, list(CbFilterDiscrete, tblist_class))`). See `vignette("custom-filters")`.