| Source | R Documentation |
R6 class representing a data source
R6 class representing a data source
Source is an object storing information about data source such as source type, primary keys and relations between stored data.
dtconnData connection object the Source if based on.
dtvalueEvaluated data connection value used for computing stats.
meta_statsComputed metadata statistics for available filters.
compute_meta_statsWhether metadata statistics for available filters are pre-computed.
descriptionSource object description list.
attributesExtra source parameters passed when source is defined.
optionsExtra configuration options.
binding_keysSource data relations expressed as binding-keys.
primary_keysSource data primary keys expressed as primary_keys.
source_codeAn expression which allows to recreate basic source structure.
available_filtersList of filter definitions available for the source.
new()Create a new 'Source' object.
Source$new(
dtconn,
...,
primary_keys = NULL,
binding_keys = NULL,
source_code = NULL,
description = NULL,
available_filters = NULL,
compute_meta_stats = getOption("cb.source_filters_meta_stats", TRUE),
options = list(display_binding = TRUE)
)dtconnAn object defining source data connection.
...Extra Source parameters. Stored within 'attributes' field.
primary_keysDefinition of data 'primary_keys', if appropriate. See primary_keys.
binding_keysDefinition of relations between data, if appropriate. See binding-keys.
source_codeA quote object that allows to recreate basic source structure. Used as a part of reproducible code output, see code.
descriptionA named list storing the source objects description. Can be accessed with description Cohort method.
available_filtersList of filter definitions available for the source.
compute_meta_statsWhether to pre-compute metadata statistics for 'available_filters'. When 'FALSE', 'meta_stats' are skipped (and filter domains fall back to live computation). Defaults to the 'cb.source_filters_meta_stats' option ('TRUE').
optionsList of options affecting methods output. Currently supported only 'display_binding' specifying whether reproducible code should include bindings definition.
A new 'Source' object of class 'Source' (and 'dtconn' object class appended).
get()Get selected 'Source' object 'attribute'.
Source$get(param)
paramName of the attribute.
get_steps()Returns filtering steps definition, if defined for 'Source'.
Source$get_steps()
add_step()Add filtering step definition.
Source$add_step(step)
stepStep definition created with step.
rm_step()Remove filtering step definition.
Source$rm_step(step_id)
step_idId of the step to be removed.
add_filter()Add filter definition to selected step.
Source$add_filter(filter, step_id)
filterFilter definition created with filter.
step_idId of the step to include the filter to. If skipped the last step is used.
rm_filter()Remove filter definition from selected step.
Source$rm_filter(step_id, filter_id)
step_idId of the step where filter is defined.
filter_idId of the filter to be removed.
update_filter()Update filter definition.
Source$update_filter(step_id, filter_id, ...)
step_idId of the step where filter is defined.
filter_idId of the filter to be updated.
...Parameters with its new values.
calc_meta_stats()Calculate metadata statistics for available filters.
Source$calc_meta_stats()
clone()The objects of this class are cloneable with this method.
Source$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.