Add filter definition
Arguments
- x
An object to add filter to.
- filter
Filter definition created with filter.
- step_id
Id of the step to add the filter to. If missing, filter is added to the last step.
- ...
Other parameters passed to specific S3 method.
- run_flow
If `TRUE`, data flow is run after the filter is added.
- hook
List of hooks describing methods to run before/after the filter is added. See hooks for more details.