View source: R/source_methods.R
| autofilter | R Documentation |
The method should analyze source data structure, generate proper filters based on the data (e.g. column types) and attach them to source.
autofilter(source, attach_as = c("step", "meta"), ...)
## Default S3 method:
autofilter(source, ...)
## S3 method for class 'tblist'
autofilter(source, attach_as = c("step", "meta"), ...)
source |
Source object. |
attach_as |
Choose whether the filters should be attached as a new step,
or list of available filters (used in filtering panel when 'new_step = "configure"').
By default in |
... |
Extra arguments passed to a specific method. |
Source object having step configuration attached.
library(cohortBuilder)
iris_source <- set_source(tblist(iris = iris)) |>
autofilter()
iris_cohort <- cohort(iris_source)
sum_up(iris_cohort)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.