Returns the filter's value intersected with its domain. When value is `NA` and domain is set, returns the domain as the effective value.
Returns the filter's value intersected with its domain. When value is `NA` and domain is set, returns the domain as the effective value.