| cb_intersect_domain | R Documentation |
Returns the filter's value intersected with its domain. When value is 'NA' and domain is set, returns the domain as the effective value.
cb_intersect_domain(filter, ...)
filter |
S7 filter object. |
... |
Additional arguments passed to methods. |
Custom filter types should implement an S7 method for this generic. The default method returns the raw value with no domain logic.
The effective value for filtering.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.