R/ai_tools.R
cb_tool_add_filters.Rd
Returns a cb_tool that adds selected filters from the source's available_filters to the cohort. The LLM chooses whether to add to a new step or the existing last step via the action argument.
cb_tool
available_filters
action
cb_tool_add_filters(cohort)
A Cohort object.
Cohort
A cb_tool object.