Skip to contents

Returns a cb_tool whose function takes no arguments and returns a structured text summary of all steps, filters, their active status, and pending state.

Usage

cb_tool_describe_state(cohort)

Arguments

cohort

A Cohort object.

Value

A cb_tool object.