R/ai_tools.R
cb_tool_describe_state.Rd
Returns a cb_tool whose function takes no arguments and returns a structured text summary of all steps, filters, their active status, and pending state.
cb_tool
cb_tool_describe_state(cohort)
A Cohort object.
Cohort
A cb_tool object.