Skip to contents

Returns a cb_tool that removes filters from a step in the cohort. If removing all filters from a step, the entire step is removed.

Usage

cb_tool_remove_filters(cohort)

Arguments

cohort

A Cohort object.

Value

A cb_tool object.