R/ai_tools.R
cb_tool_remove_filters.Rd
Returns a cb_tool that removes filters from a step in the cohort. If removing all filters from a step, the entire step is removed.
cb_tool
cb_tool_remove_filters(cohort)
A Cohort object.
Cohort
A cb_tool object.