| cb_tool_remove_filters | R Documentation |
Returns a cb_tool that removes filters from a step in the
cohort. If removing all filters from a step, the entire step is removed.
cb_tool_remove_filters(cohort)
cohort |
A |
A cb_tool object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.