Skip to contents

Returns a cb_tool that triggers data calculations for the entire cohort or a specific step. Only functional when the cb_tool_run_cohort option is FALSE; otherwise returns an informative message that the cohort runs automatically.

Usage

cb_tool_run(cohort)

Arguments

cohort

A Cohort object.

Value

A cb_tool object.