R/ai_tools.R
cb_tool_set_filter_values.Rd
Returns a cb_tool that updates filter parameter values on the last step of the cohort and triggers the data pipeline.
cb_tool
cb_tool_set_filter_values(cohort)
A Cohort object.
Cohort
A cb_tool object.