| .default_filter_name | R Documentation |
Single-variable filters are named after their variable. Multi-variable filters get a summarised name listing the first two variables, the count of remaining variables, and the filter type, e.g. '"age sex + 2 vars multi_discrete"'.
.default_filter_name(variables, type)
variables |
Character vector of variable names. |
type |
Filter type string (e.g. '"multi_discrete"', '"query"'). |
A single character string suitable for use as a filter name.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.