Skip to contents

Method for printing filter details

Usage

.print_filter(filter, data_objects, to_string = FALSE)

# Default S3 method
.print_filter(filter, data_objects, to_string = FALSE)

Arguments

filter

The defined filter object.

data_objects

List of data objects for the underlying filtering step.

to_string

If `TRUE`, return the output as a character vector instead of printing it. Defaults to `FALSE`.