Create data connection as a list of loaded data frames.
The object should be used as `dtconn` argument of set_source.
Usage
tblist(..., names, .class = NULL)
as.tblist(x, ..., .class = NULL)
Value
Object of class 'tblist' being a named list of data frames.
Arguments
...
additional arguments to be passed to or from methods.
names
A character vector describing provided tables names.
If missing names are constructed based on provided tables objects.
.class
The extra (highest priority) class added to the resulting object.
Having the extra class defined, enables to implement custom S3 methods for the object
having higher priority over the existing methods.
Especially useful if you want to change the built-in method behavior.